/* 
 Tiny 45,  Interner Oszillator mit 1MHz, 
 (Vorteiler /8 eingeschaltet)
 
 Layout:
                      Reset  1    8  +5V
           Sensor2 ADC3 PB3  2     7  PB2 
           Sensor1 ADC2 PB4  3     6  PB1 
                        GND  4     5  PB0 Transistor


          Sensor2 bisher nicht implementiert
*/

#define F_CPU 1000000UL	/* CPU clock in Hertz */

#include <avr/io.h>
#include <util/delay.h>

#define LED_AUS {PORTB&=~BIT0;}
#define LED_EIN {PORTB|=BIT0;}

#define U8 unsigned char
#define U16 unsigned int
#define BIT0 1
#define BIT1 2
#define BIT2 4
#define BIT3 8
#define BIT4 16


int main(void){
  U8 Unew=127;
  U8 Uold=127;
  U8 diff;
  U16 timer=0;
  U8 n;

  DDRB=BIT0;
  PORTB=BIT1|BIT2|BIT3; //Pull-Up auf unbenutzte Eingaenge
  ADMUX=(1<<ADLAR) | 2; //Uref=5V CH=ADC2
  ADCSRA=(1<<ADEN) | (1<<ADSC) |(1<<ADPS1) | (1<<ADPS0); // /8 = 125KHz
  ACSR=(1<<ACD); //Analogkomparator aus
  TCCR1 = (1<<CS13) |(1<<CS12) |(1<<CS11) |(1<<CS10) | (1<<CTC1); // /16384, CTC Modus; -->61,02Hz
  OCR1A=0;
  OCR1C = 60; //div 61
  PRR=(1<<PRTIM0)|(1<<PRUSI);
  n=10;
  while(--n){
     LED_EIN;
     _delay_ms(60);
     LED_AUS;
     _delay_ms(60);
  }

  while(1){
      ADCSRA|=(1<<ADSC); //Alle 0.1ms
      _delay_us(60);
      while (ADCSRA & (1<<ADSC))
       ;
      Unew=ADCH;
      if (Uold > Unew){
        diff = Uold - Unew;
      }else{
        diff = Unew - Uold;
      }
      Uold = Unew;
      if (diff > 25) timer = 8*60; // Timer in Sekunden

      if (timer > 0){
        LED_EIN;
      }else{
        LED_AUS;
      }

      if (TIFR & (1<<OCF1A)){ //Sekunde rum
        TIFR |= (1<<OCF1A);
        if (timer>0) timer--;
      }
      _delay_us(40); 

  }
}
